@@ -139,7 +139,8 @@ int main(int argc, char *argv[])
 
 	nilfs = nilfs_open(dev, NULL, NILFS_OPEN_RDWR | NILFS_OPEN_GCLK);
 	if (nilfs == NULL) {
-		fprintf(stderr, "%s: %s: cannot open NILFS\n", progname, dev);
+		fprintf(stderr, "%s: cannot open NILFS on %s: %m\n",
+			progname, dev ? : "device");
 		exit(1);
 	}
 
