@@ -290,7 +290,7 @@ static int lssu_get_protcno(struct nilfs *nilfs,
 	ret = nilfs_cnoconv_time2cno(cnoconv, *prottimep, protcnop);
 	if (ret < 0) {
 		fprintf(stderr,
-			"%s: cannot convert protectoin time to checkpoint "
+			"%s: cannot convert protection time to checkpoint "
 			"number: %m\n",
 			progname);
 	}
@@ -382,8 +382,8 @@ int main(int argc, char *argv[])
 
 	nilfs = nilfs_open(dev, NULL, open_flags);
 	if (nilfs == NULL) {
-		fprintf(stderr, "%s: %s: cannot open NILFS\n",
-			progname, dev);
+		fprintf(stderr, "%s: cannot open NILFS on %s: %m\n",
+			progname, dev ? : "device");
 		exit(1);
 	}
 
