@@ -411,9 +411,9 @@ struct nilfs *nilfs_open(const char *dev, const char *dir, int flags)
 	    (NILFS_OPEN_RDONLY | NILFS_OPEN_WRONLY | NILFS_OPEN_RDWR)) {
 		if (nilfs_find_fs(nilfs, dev, dir, MNTOPT_RW) < 0) {
 			if (!(flags & NILFS_OPEN_RDONLY))
-				goto out_nilfs;
+				goto out_fd;
 			if (nilfs_find_fs(nilfs, dev, dir, MNTOPT_RO) < 0)
-				goto out_nilfs;
+				goto out_fd;
 		}
 		nilfs->n_iocfd = open(nilfs->n_ioc, O_RDONLY);
 		if (nilfs->n_iocfd < 0)
@@ -435,14 +435,10 @@ out_fd:
 		close(nilfs->n_devfd);
 	if (nilfs->n_iocfd >= 0)
 		close(nilfs->n_iocfd);
-	if (nilfs->n_dev != NULL)
-		free(nilfs->n_dev);
-	if (nilfs->n_ioc != NULL)
-		free(nilfs->n_ioc);
-	if (nilfs->n_sb != NULL)
-		free(nilfs->n_sb);
 
-out_nilfs:
+	free(nilfs->n_dev);
+	free(nilfs->n_ioc);
+	free(nilfs->n_sb);
 	free(nilfs);
 	return NULL;
 }
@@ -459,12 +455,10 @@ void nilfs_close(struct nilfs *nilfs)
 		close(nilfs->n_devfd);
 	if (nilfs->n_iocfd >= 0)
 		close(nilfs->n_iocfd);
-	if (nilfs->n_dev != NULL)
-		free(nilfs->n_dev);
-	if (nilfs->n_ioc != NULL)
-		free(nilfs->n_ioc);
-	if (nilfs->n_sb != NULL)
-		free(nilfs->n_sb);
+
+	free(nilfs->n_dev);
+	free(nilfs->n_ioc);
+	free(nilfs->n_sb);
 	free(nilfs);
 }
 
